@@ -9,9 +9,6 @@ PUPPETDB_CERT = None
 PUPPETDB_TIMEOUT = 20
 DEFAULT_ENVIRONMENT = 'production'
 SECRET_KEY = os.urandom(24)
-DEV_LISTEN_HOST = '127.0.0.1'
-DEV_LISTEN_PORT = 5555
-DEV_COFFEE_LOCATION = 'coffee'
 UNRESPONSIVE_HOURS = 2
 ENABLE_QUERY = True
 # Uncomment to restrict the enabled PuppetDB endpoints in the query page.
@@ -43,16 +40,31 @@ GRAPH_FACTS = ['architecture',
                'osfamily',
                'puppetversion',
                'processorcount']
-INVENTORY_FACTS = [('Hostname', 'fqdn'),
+INVENTORY_FACTS = [('Hostname', 'trusted'),
                    ('IP Address', 'ipaddress'),
-                   ('OS', 'lsbdistdescription'),
+                   ('OS', 'os'),
                    ('Architecture', 'hardwaremodel'),
                    ('Kernel Version', 'kernelrelease'),
                    ('Puppet Version', 'puppetversion'), ]
+
+INVENTORY_FACT_TEMPLATES = {
+    'trusted': (
+        """<a href="{{url_for('node', env=current_env, node_name=value.certname)}}">"""
+        """{{value.hostname}}"""
+        """</a>"""
+    ),
+    'os': "{{ fact_os_detection(value) }}",
+}
 REFRESH_RATE = 30
 DAILY_REPORTS_CHART_ENABLED = True
 DAILY_REPORTS_CHART_DAYS = 8
 WITH_EVENT_NUMBERS = True
-
 SHOW_ERROR_AS = 'friendly'  # or 'raw'
 CODE_PREFIX_TO_REMOVE = '/etc/puppetlabs/code/environments(/.*?/modules)?'
+FAVORITE_ENVS = [
+    'production',
+    'staging',
+    'qa',
+    'test',
+    'dev',
+]
